======================================
Package Api Documentation for mlconjug
======================================


API Reference for the classes in mlconjug3.mlconjug.py
------------------------------------------------------

.. automodule:: mlconjug3.mlconjug
    :member-order: bysource
    :members:
    :private-members:
    :show-inheritance:


API Reference for the classes in mlconjug3.PyVerbiste.py
--------------------------------------------------------

.. automodule:: mlconjug3.PyVerbiste
    :member-order: bysource
    :members:
    :private-members:
    :inherited-members:
    :show-inheritance:
